@@ -2,7 +2,7 @@ package Test2::Harness::Run::Job;
 use strict;
 use warnings;
 
-our $VERSION = '2.000001'; # TRIAL
+our $VERSION = '2.000002'; # TRIAL
 
 use Carp qw/croak/;
 use Config qw/%Config/;
@@ -65,7 +65,7 @@ sub launch_command {
 
     if ($self->test_file->non_perl) {
         $run_file = "./$run_file" unless $run_file =~ m{^[/\.]};
-        return ([$run_file, @{$ts->args // []}], {PERL5LIB => join $Config{path_sep} => @includes, $ENV{PERL5LIB}});
+        return ([$run_file, @{$ts->args // []}], {PERL5LIB => join($Config{path_sep} => @includes, $ENV{PERL5LIB})});
     }
 
     @includes = map { "-I$_" } @includes;
@@ -92,7 +92,7 @@ sub launch_command {
         @loads,
         $run_file,
         @{$self->args // []},
-        @{$ts->args // []},
+        @{$ts->args   // []},
     ];
 }
 
